## File: PDL::CCS::Version.pm
## Author: Bryan Jurish
## Description: set version for PDL::CCS

package PDL::CCS;
our $VERSION=1.14;

1; ##-- make perl happy
